==> generator-jumper-0.1.3.tgz: package/app/index.js <==
'use strict';
var util = require('util');
var path = require('path');
var spawn = require('child_process').spawn;
var yeoman = require('yeoman-generator');


var JumperGenerator = module.exports = function JumperGenerator(args, options, config) {
  yeoman.generators.Base.apply(this, arguments);
  this.appname = path.basename(process.cwd());

    // setup the test-framework property, Gruntfile template will need this
  this.testFramework = options['test-framework'] || 'mocha';

  // for hooks to resolve on mocha by default
  if (!options['test-framework']) {
    options['test-framework'] = 'mocha';
  }

  // resolved to mocha by default (could be switched to jasmine for instance)
  this.hookFor('test-framework', { as: 'app' });

  this.mainCoffeeFile = 'console.log "\'Allo from CoffeeScript!"';

  this.pkg = JSON.parse(this.readFileAsString(path.join(__dirname, '../package.json')));
};

util.inherits(JumperGenerator, yeoman.generators.Base);

JumperGenerator.prototype.askFor = function askFor() {
  var cb = this.async();

  // have Yeoman greet the user.
  console.log(this.yeoman);
  console.log('Out of the box I include HTML5 Boilerplate and jQuery.');

  var prompts = [
  {
    type: 'list',
    name: 'frameworkChoice',
    message: 'Would you like to include a mobile-first UI framework?',
    choices: [{
      name: 'Foundation 5',
      value: 'foundation'
    },{
      name: 'Twitter Bootstrap 3',
      value: 'bootstrap'
    }, {
      name: 'Without Framework',
      value: 'noframework'
    }]
  }, {
    type: 'confirm',
    name: 'likeSass',
    message: 'Would you like to use the Sass in new project?',
    default: true
  }, {
    type: 'confirm',
    name: 'coffee',
    message: 'Would you like to use the CoffeeScript?',
    default: false
  }, {
    type: 'checkbox',
    name: 'features',
    message: 'What more would you like?',
    choices: [{
      name: 'Modernizr',
      value: 'includeModernizr',
      checked: true
    }, {
      name: 'Handlebars',
      value: 'includeHandlebars',
      checked: false
    },
    {
      name: 'Autoprefixer',
      value: 'includeAutoprefixer',
      checked: true
    },
    {
      name: 'FastClick.js',
      value: 'fastclickChoice',
      checked: true
    }]
  }, {
    type:'confirm',
    name:'favicons',
    message: 'Would you like multiple favicons for different devices (number resolutions for different iOS devices)?',
    default: false
  }];

  this.prompt(prompts, function (props) {
    var features = props.features;

    function hasFeature(feat) { return features.indexOf(feat) !== -1; }

    this.frameworkSelected = props.frameworkChoice;
    this.likeSass = props.likeSass;
    this.includeModernizr = hasFeature('includeModernizr');
    this.includeHandlebars = hasFeature('includeHandlebars');
    this.includeAutoprefixer = hasFeature('includeAutoprefixer');
    this.fastclickChoice = hasFeature('fastclickChoice');
    this.favicons = props.favicons;
    this.coffee = props.coffee;

    cb();
  }.bind(this));
};

JumperGenerator.prototype.readIndex = function readIndex() {
  this.indexFile = this.readFileAsString(path.join(this.sourceRoot(), 'index.html'));
  this.indexFile = this.engine(this.indexFile, this);
}

JumperGenerator.prototype.handlebarsjs = function handlebarsjs() {
  if (this.includeHandlebars) {
    this.indexFile = this.appendScripts(this.indexFile, 'js/handlebars.js', [
      "bower_components/handlebars.js/dist/handlebars.js"
      ]);
  }
}

JumperGenerator.prototype.mainStylesheet = function mainStylesheet() {
  if(this.frameworkSelected == 'noframework') {
    this.copy('app.css', 'app/css/main.css');
  } else if (this.frameworkSelected == 'bootstrap') {
    this.template('bootstrap.' + (this.likeSass ? 's' : '') + 'css', 'app/'+ (this.likeSass ? 's' : '') +'css/main.' + (this.likeSass ? 's' : '') + 'css');
  } else if (this.frameworkSelected == 'foundation' && this.likeSass) {
    this.template('foundation.' + 'scss', 'app/scss/main.scss');
  } else if (this.frameworkSelected == 'foundation' && !this.likeSass) {
    this.indexFile = this.appendStyles(this.indexFile, '/bower_components/foundation/css/foundation.css', ["/bower_components/foundation/css/foundation.css"]);
  }
};

JumperGenerator.prototype.git = function git() {
  this.copy('gitignore', '.gitignore');
};

JumperGenerator.prototype.projectfiles = function projectfiles() {
  this.copy('editorconfig', '.editorconfig');
  this.copy('jshintrc', '.jshintrc');
};
JumperGenerator.prototype.packageJSON = function packageJSON() {
  this.template('_package.json', 'package.json');
}
JumperGenerator.prototype.gruntfile = function gruntfile() {
  this.template('Gruntfile.js');
}

JumperGenerator.prototype.bower = function bower() {
  this.template('_bower.json', 'bower.json');
  this.copy('bowerrc', '.bowerrc');
}

JumperGenerator.prototype.fastclick = function fastclick() {
  if (this.fastclickChoice) {
    this.copy('fastclick.js', 'app/js/fastclick.js');
    this.copy('fastclick.example.js', 'app/js/fastclick.init.js');
    this.indexFile = this.appendScripts(this.indexFile, 'js/fastClick.js', [
        "js/fastclick.js",
        "js/fastclick.init.js"
      ]);
  }
};

JumperGenerator.prototype.coffeeFiles = function coffeeFiles() {
  if (this.coffee) {
    this.indexFile = this.appendFiles({
      html: this.indexFile,
      fileType: 'js',
      optimizedPath: 'js/coffee.js',
      sourceFileList: ['js/hello.js'],
      searchPath: '.tmp'
    });
  }
};

JumperGenerator.prototype.writeIndex = function writeIndex() {
  var fndir = 'bower_components/foundation/js/foundation/';
  if (this.frameworkSelected == 'foundation') {
    this.indexFile = this.appendScripts(this.indexFile, 'js/foundation.js', [
      fndir + "foundation.js",
      fndir + "foundation.abide.js",
      fndir + "foundation.accordion.js",
      fndir + "foundation.alert.js",
      fndir + "foundation.clearing.js",
      fndir + "foundation.dropdown.js",
      fndir + "foundation.interchange.js",
      fndir + "foundation.joyride.js",
      fndir + "foundation.magellan.js",
      fndir + "foundation.offcanvas.js",
      fndir + "foundation.orbit.js",
      fndir + "foundation.reveal.js",
      fndir + "foundation.tab.js",
      fndir + "foundation.tooltip.js",
      fndir + "foundation.topbar.js"
      ]);
  } else if (this.frameworkSelected == 'bootstrap') {
    this.indexFile = this.appendScripts(this.indexFile, 'js/bootstrap.min.js', [
        "bower_components/sass-bootstrap/js/affix.js",
        "bower_components/sass-bootstrap/js/alert.js",
        "bower_components/sass-bootstrap/js/dropdown.js",
        "bower_components/sass-bootstrap/js/tooltip.js",
        "bower_components/sass-bootstrap/js/modal.js",
        "bower_components/sass-bootstrap/js/transition.js",
        "bower_components/sass-bootstrap/js/button.js",
        "bower_components/sass-bootstrap/js/popover.js",
        "bower_components/sass-bootstrap/js/carousel.js",
        "bower_components/sass-bootstrap/js/scrollspy.js",
        "bower_components/sass-bootstrap/js/collapse.js",
        "bower_components/sass-bootstrap/js/tab.js"
      ]);
  }
};

JumperGenerator.prototype.app = function app() {
  this.mkdir('app');
  this.mkdir('app/css');
  this.mkdir('app/fonts');
  this.mkdir('app/img');
  this.mkdir('app/js');
  if (this.likeSass) {
    this.mkdir('app/scss');
  }
  this.write('app/index.html', this.indexFile);

  if (this.frameworkSelected == 'bootstrap') {
    this.copy('fonts/glyphicons-halflings-regular.eot', 'app/fonts/glyphicons-halflings-regular.eot');
    this.copy('fonts/glyphicons-halflings-regular.svg', 'app/fonts/glyphicons-halflings-regular.svg');
    this.copy('fonts/glyphicons-halflings-regular.ttf', 'app/fonts/glyphicons-halflings-regular.ttf');
    this.copy('fonts/glyphicons-halflings-regular.woff', 'app/fonts/glyphicons-halflings-regular.woff');
  }

  this.copy('favicon.ico', 'app/favicon.ico');
  this.copy('404.html', 'app/404.html');
  this.copy('robots.txt', 'app/robots.txt');
  this.copy('htaccess', 'app/.htaccess');

  if (this.coffee) {
    this.write('app/js/hello.coffee', this.mainCoffeeFile);
  }
};

JumperGenerator.prototype.install = function () {
  if (this.options['skip-install']) {
    return;
  }

  var done = this.async();
  this.installDependencies({
    skipMessage: this.options['skip-install-message'],
    skipInstall: this.options['skip-install'],
    callback: done
  });
};

==> generator-jumper-0.1.4.tgz: package/app/index.js <==
'use strict';
var util = require('util');
var path = require('path');
var spawn = require('child_process').spawn;
var yeoman = require('yeoman-generator');


var JumperGenerator = module.exports = function JumperGenerator(args, options, config) {
  yeoman.generators.Base.apply(this, arguments);
  this.appname = path.basename(process.cwd());

    // setup the test-framework property, Gruntfile template will need this
  this.testFramework = options['test-framework'] || 'mocha';

  // for hooks to resolve on mocha by default
  if (!options['test-framework']) {
    options['test-framework'] = 'mocha';
  }
  
  this.options = options;

  // resolved to mocha by default (could be switched to jasmine for instance)
  this.hookFor('test-framework', {
    as: 'app',
    options: {
      options: {
        'skip-install': options['skip-install-message'],
        'skip-message': options['skip-install']
      }
    }
  });

  this.mainCoffeeFile = 'console.log "\'Allo from CoffeeScript!"';

  this.pkg = JSON.parse(this.readFileAsString(path.join(__dirname, '../package.json')));
};

util.inherits(JumperGenerator, yeoman.generators.Base);

JumperGenerator.prototype.askFor = function askFor() {
  var cb = this.async();

  // have Yeoman greet the user.
  console.log(this.yeoman);
  console.log('Out of the box I include HTML5 Boilerplate and jQuery.');

  var prompts = [
  {
    type: 'list',
    name: 'frameworkChoice',
    message: 'Would you like to include a mobile-first UI framework?',
    choices: [{
      name: 'Foundation 5',
      value: 'foundation'
    },{
      name: 'Twitter Bootstrap 3',
      value: 'bootstrap'
    }, {
      name: 'Without Framework',
      value: 'noframework'
    }]
  }, {
    type: 'confirm',
    name: 'likeSass',
    message: 'Would you like to use the Sass in new project?',
    default: true
  }, {
    type: 'confirm',
    name: 'coffee',
    message: 'Would you like to use the CoffeeScript?',
    default: false
  }, {
    type: 'checkbox',
    name: 'features',
    message: 'What more would you like?',
    choices: [{
      name: 'Modernizr',
      value: 'includeModernizr',
      checked: true
    }, {
      name: 'Handlebars',
      value: 'includeHandlebars',
      checked: false
    },
    {
      name: 'Autoprefixer',
      value: 'includeAutoprefixer',
      checked: true
    },
    {
      name: 'FastClick.js',
      value: 'fastclickChoice',
      checked: true
    }]
  }, {
    type:'confirm',
    name:'favicons',
    message: 'Would you like multiple favicons for different devices (number resolutions for different iOS devices)?',
    default: false
  }];

  this.prompt(prompts, function (props) {
    var features = props.features;

    function hasFeature(feat) { return features.indexOf(feat) !== -1; }

    this.frameworkSelected = props.frameworkChoice;
    this.likeSass = props.likeSass;
    this.includeModernizr = hasFeature('includeModernizr');
    this.includeHandlebars = hasFeature('includeHandlebars');
    this.includeAutoprefixer = hasFeature('includeAutoprefixer');
    this.fastclickChoice = hasFeature('fastclickChoice');
    this.favicons = props.favicons;
    this.coffee = props.coffee;

    cb();
  }.bind(this));
};

JumperGenerator.prototype.readIndex = function readIndex() {
  this.indexFile = this.readFileAsString(path.join(this.sourceRoot(), 'index.html'));
  this.indexFile = this.engine(this.indexFile, this);
}

JumperGenerator.prototype.handlebarsjs = function handlebarsjs() {
  if (this.includeHandlebars) {
    this.indexFile = this.appendScripts(this.indexFile, 'js/handlebars.js', [
      "bower_components/handlebars.js/dist/handlebars.js"
      ]);
  }
}

JumperGenerator.prototype.mainStylesheet = function mainStylesheet() {
  if(this.frameworkSelected == 'noframework') {
    this.copy('app.css', 'app/css/main.css');
  } else if (this.frameworkSelected == 'bootstrap') {
    this.template('bootstrap.' + (this.likeSass ? 's' : '') + 'css', 'app/'+ (this.likeSass ? 's' : '') +'css/main.' + (this.likeSass ? 's' : '') + 'css');
  } else if (this.frameworkSelected == 'foundation' && this.likeSass) {
    this.template('foundation.' + 'scss', 'app/scss/main.scss');
  } else if (this.frameworkSelected == 'foundation' && !this.likeSass) {
    this.indexFile = this.appendStyles(this.indexFile, '/bower_components/foundation/css/foundation.css', ["/bower_components/foundation/css/foundation.css"]);
  }
};

JumperGenerator.prototype.git = function git() {
  this.copy('gitignore', '.gitignore');
};

JumperGenerator.prototype.projectfiles = function projectfiles() {
  this.copy('editorconfig', '.editorconfig');
  this.copy('jshintrc', '.jshintrc');
};
JumperGenerator.prototype.packageJSON = function packageJSON() {
  this.template('_package.json', 'package.json');
}
JumperGenerator.prototype.gruntfile = function gruntfile() {
  this.template('Gruntfile.js');
}

JumperGenerator.prototype.bower = function bower() {
  this.template('_bower.json', 'bower.json');
  this.copy('bowerrc', '.bowerrc');
}

JumperGenerator.prototype.fastclick = function fastclick() {
  if (this.fastclickChoice) {
    this.copy('fastclick.js', 'app/js/fastclick.js');
    this.copy('fastclick.example.js', 'app/js/fastclick.init.js');
    this.indexFile = this.appendScripts(this.indexFile, 'js/fastClick.js', [
        "js/fastclick.js",
        "js/fastclick.init.js"
      ]);
  }
};

JumperGenerator.prototype.coffeeFiles = function coffeeFiles() {
  if (this.coffee) {
    this.indexFile = this.appendFiles({
      html: this.indexFile,
      fileType: 'js',
      optimizedPath: 'js/coffee.js',
      sourceFileList: ['js/hello.js'],
      searchPath: '.tmp'
    });
  }
};

JumperGenerator.prototype.writeIndex = function writeIndex() {
  var fndir = 'bower_components/foundation/js/foundation/';
  if (this.frameworkSelected == 'foundation') {
    this.indexFile = this.appendScripts(this.indexFile, 'js/foundation.js', [
      fndir + "foundation.js",
      fndir + "foundation.abide.js",
      fndir + "foundation.accordion.js",
      fndir + "foundation.alert.js",
      fndir + "foundation.clearing.js",
      fndir + "foundation.dropdown.js",
      fndir + "foundation.interchange.js",
      fndir + "foundation.joyride.js",
      fndir + "foundation.magellan.js",
      fndir + "foundation.offcanvas.js",
      fndir + "foundation.orbit.js",
      fndir + "foundation.reveal.js",
      fndir + "foundation.tab.js",
      fndir + "foundation.tooltip.js",
      fndir + "foundation.topbar.js"
      ]);
  } else if (this.frameworkSelected == 'bootstrap') {
    this.indexFile = this.appendScripts(this.indexFile, 'js/bootstrap.min.js', [
        "bower_components/sass-bootstrap/js/affix.js",
        "bower_components/sass-bootstrap/js/alert.js",
        "bower_components/sass-bootstrap/js/dropdown.js",
        "bower_components/sass-bootstrap/js/tooltip.js",
        "bower_components/sass-bootstrap/js/modal.js",
        "bower_components/sass-bootstrap/js/transition.js",
        "bower_components/sass-bootstrap/js/button.js",
        "bower_components/sass-bootstrap/js/popover.js",
        "bower_components/sass-bootstrap/js/carousel.js",
        "bower_components/sass-bootstrap/js/scrollspy.js",
        "bower_components/sass-bootstrap/js/collapse.js",
        "bower_components/sass-bootstrap/js/tab.js"
      ]);
  }
};

JumperGenerator.prototype.app = function app() {
  this.mkdir('app');
  this.mkdir('app/css');
  this.mkdir('app/fonts');
  this.mkdir('app/img');
  this.mkdir('app/js');
  if (this.likeSass) {
    this.mkdir('app/scss');
  }
  this.write('app/index.html', this.indexFile);

  if (this.frameworkSelected == 'bootstrap') {
    this.copy('fonts/glyphicons-halflings-regular.eot', 'app/fonts/glyphicons-halflings-regular.eot');
    this.copy('fonts/glyphicons-halflings-regular.svg', 'app/fonts/glyphicons-halflings-regular.svg');
    this.copy('fonts/glyphicons-halflings-regular.ttf', 'app/fonts/glyphicons-halflings-regular.ttf');
    this.copy('fonts/glyphicons-halflings-regular.woff', 'app/fonts/glyphicons-halflings-regular.woff');
  }

  this.copy('favicon.ico', 'app/favicon.ico');
  this.copy('404.html', 'app/404.html');
  this.copy('robots.txt', 'app/robots.txt');
  this.copy('htaccess', 'app/.htaccess');

  if (this.coffee) {
    this.write('app/js/hello.coffee', this.mainCoffeeFile);
  }
};

JumperGenerator.prototype.install = function () {
  if (this.options['skip-install']) {
    return;
  }

  var done = this.async();
  this.installDependencies({
    skipMessage: this.options['skip-install-message'],
    skipInstall: this.options['skip-install'],
    callback: done
  });
};
